__author__ = "Sebastien Celles"
__copyright__ = "Copyright 2015, celles.net"
__credits__ = ["Sebastien Celles"]
__license__ = "GPL"
__version__ = "0.0.1"
__maintainer__ = "Sebastien Celles"
__email__ = "s.celles@gmail.com"
__status__ = "Development"
__url__ = 'https://github.com/scls19fr/pyCitizenBand'
